fractional_sumcheck

Function fractional_sumcheck 

pub fn fractional_sumcheck<SC: StarkProtocolConfig, TS: FiatShamirTranscript<SC>>(
    transcript: &mut TS,
    evals: &[Frac<SC::EF>],
    assert_zero: bool,
) -> Result<(FracSumcheckProof<SC>, Vec<SC::EF>), LogupZerocheckError>
Runs the fractional sumcheck protocol using GKR layered circuit.

Arguments

  • transcript - The Fiat-Shamir transcript
  • evals - list of (p, q) pairs of fractions in projective coordinates representing evaluations on the hypercube
  • assert_zero - Whether to assert that the final sum is zero. If true, then the transcript will not observe the numerator of the final sum.

Returns

The fractional sumcheck proof and the final random evaluation vector.